<?php

namespace Drupal\views_raw_sql\Plugin\views\argument;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\argument\ArgumentPluginBase;

/**
 * Argument handler to accept a numeric range.
 *
 * @ingroup views_argument_handlers
 *
 * @ViewsArgument("argument_views_raw_sql")
 */
class RawSQLArgument extends ArgumentPluginBase {

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['where_raw_sql'] = ['default' => NULL];
    return $options;
  }

  /**
   * Build the options form.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['where_raw_sql'] = [
      '#type' => 'textfield',
      '#title' => t('Raw SQL'),
      '#default_value' => $this->options['where_raw_sql'],
      '#weight' => -6,
    ];
  }

  /**
   * Create the query.
   */
  public function query($group_by = FALSE) {
    $this->ensureMyTable();
    $raw_sql = $this->options['where_raw_sql'];
    $argument = $this->argument;
    $raw_sql = str_replace('%argument%', $argument, $raw_sql);
    $this->query->addWhereExpression($this->options['group'], $raw_sql);
  }

}
