<?php

namespace Drupal\views_raw_sql\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\field\NumericField;

/**
 * @file
 * Defines Drupal\views_raw_sql\Plugin\views\field\RawSQL.
 */

/**
 * Field handler to flag the node type.
 *
 * @ingroup views_field_handlers
 * @ViewsField("field_views_raw_sql")
 */
class RawSQLField extends NumericField {

  /**
   * Sets the initial field data at zero.
   */
  public function query() {
    $this->ensureMyTable();
    // Add the field.
    $group_type = $this->options['group_type'];
    $params = $group_type != 'group' ? ['function' => $group_type] : [];

    $sql = $this->options['raw_sql'];
    $this->field_alias = $this->query->addField(NULL, $sql, 'raw_sql_field', $params);
    $this->addAdditionalFields();
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['raw_sql'] = ['default' => NULL];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['raw_sql'] = [
      '#type' => 'textfield',
      '#title' => t('Raw SQL'),
      '#default_value' => $this->options['raw_sql'],
      '#weight' => -6,
    ];
  }

}
